Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(358)

Unified Diff: chrome/browser/prefs/profile_pref_store_manager.h

Issue 2634403002: Use GetDeterministicMachineSpecificId instead of RLZ for device_id (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/prefs/profile_pref_store_manager.h
diff --git a/chrome/browser/prefs/profile_pref_store_manager.h b/chrome/browser/prefs/profile_pref_store_manager.h
index 8ccb4558e909f99663d4909fd8bff87390414e75..e1d0898a000800198770c1a4e40ec96486e433de 100644
--- a/chrome/browser/prefs/profile_pref_store_manager.h
+++ b/chrome/browser/prefs/profile_pref_store_manager.h
@@ -40,15 +40,16 @@ class ProfilePrefStoreManager {
// |tracking_configuration| is used for preference tracking.
// |reporting_ids_count| is the count of all possible tracked preference IDs
// (possibly greater than |tracking_configuration.size()|).
// |seed| and |device_id| are used to track preference value changes and must
// be the same on each launch in order to verify loaded preference values.
ProfilePrefStoreManager(
const base::FilePath& profile_path,
const std::vector<PrefHashFilter::TrackedPreferenceMetadata>&
tracking_configuration,
size_t reporting_ids_count,
const std::string& seed,
- const std::string& device_id,
+ const std::string& legacy_device_id,
PrefService* local_state);
~ProfilePrefStoreManager();
@@ -117,7 +118,7 @@ class ProfilePrefStoreManager {
tracking_configuration_;
const size_t reporting_ids_count_;
const std::string seed_;
- const std::string device_id_;
+ const std::string legacy_device_id_;
PrefService* local_state_;
DISALLOW_COPY_AND_ASSIGN(ProfilePrefStoreManager);
« no previous file with comments | « chrome/browser/prefs/chrome_pref_service_factory.cc ('k') | chrome/browser/prefs/profile_pref_store_manager.cc » ('j') | no next file with comments »
@@ -40,15 +40,16 @@ class ProfilePrefStoreManager {
// |reporting_ids_count| is the count of all possible tracked preference IDs
// (possibly greater than |tracking_configuration.size()|).
- // |seed| and |device_id| are used to track preference value changes and must
- // be the same on each launch in order to verify loaded preference values.
+ // |seed| and |legacy_device_id| are used to track preference value changes
+ // and must be the same on each launch in order to verify loaded preference
+ // values.
ProfilePrefStoreManager(
const base::FilePath& profile_path,

Powered by Google App Engine
This is Rietveld 408576698